package com.diagbot.facade;

import com.diagbot.biz.push.entity.Lis;
import com.diagbot.biz.push.entity.Pacs;
import com.diagbot.dto.IndicationDTO;
import com.diagbot.dto.WordCrfDTO;
import com.diagbot.enums.LibTypeEnum;
import com.diagbot.enums.RuleTypeEnum;
import com.diagbot.enums.TypeEnum;
import com.diagbot.process.CriticalProcess;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.RuleVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

/**
 * @Description: 危急值facade
 * @author: zhoutg
 * @time: 2018/8/6 9:11
 */
@Component
public class CriticalFacade {

    @Autowired
    NeoFacade neoFacade;
    @Autowired
    CriticalProcess criticalProcess;
    @Autowired
    CommonFacade commonFacade;

    /**
     * 危急值提示
     * @param
     * @return
     */
    public void criticalFac(WordCrfDTO wordCrfDTO, IndicationDTO res) {
        // 化验危急值
        criticalProcess.processLis(wordCrfDTO, res);
        // 辅检危急值
        criticalProcess.processPacs(wordCrfDTO, res);
        // 结果去重处理
        commonFacade.dealMsg(res.getCriticalValList());
    }



    /**
     * 获取危急值入参
     *
     * @param wordCrfDTO
     * @return
     */
    public List<RuleVO> getRuleVO(WordCrfDTO wordCrfDTO) {
        List<RuleVO> ruleVOList = new ArrayList<>();
        // 化验数值
        List<Lis> lisList = wordCrfDTO.getLis();
        for (Lis lis : lisList) {
            if (StringUtil.isNotBlank(lis.getUniqueName())) {
                RuleVO ruleVO = new RuleVO();
                ruleVO.setInputName(lis.getName());
                ruleVO.setLibName(lis.getUniqueName());
                ruleVO.setLibType(LibTypeEnum.lis.getKey());
                ruleVO.setLibTypeName(TypeEnum.lis.getName());
                ruleVO.setDateValue(lis.getDateValue());
                ruleVO.setSuffix(String.valueOf(RuleTypeEnum.critical.getKey()));
                ruleVOList.add(ruleVO);
            }
        }

        // 辅检
        List<Pacs> pacsList = wordCrfDTO.getPacs();
        for (Pacs pacs : pacsList) {
            if (StringUtil.isNotBlank(pacs.getUniqueName())) {
                RuleVO ruleVO = new RuleVO();
                ruleVO.setInputName(pacs.getName());
                ruleVO.setLibName(pacs.getUniqueName());
                ruleVO.setLibType(LibTypeEnum.pacs.getKey());
                ruleVO.setLibTypeName(TypeEnum.pacs.getName());
                ruleVO.setDateValue(pacs.getDateValue());
                ruleVOList.add(ruleVO);
            }
        }
        return ruleVOList;
    }
}
